@@ -91,7 +91,6 @@ class B_Trainer:
         :param isSpikingjelly12: 是否为SNN
         :param isSpikingjelly14: 是否为SNN
         '''
-        super().__init__()
         self.train_loss_batches_lst = []
         self.train_loss_epoch_lst = []
         self.train_acc_lst = []
@@ -186,7 +185,7 @@ class B_Trainer:
         model_state_dict = checkpoint['model']
 
         flag_model = isinstance(self.model, nn.DataParallel)
-        flag_dict = list(model_state_dict._keys())[0].startswith('module.')
+        flag_dict = list(model_state_dict.keys())[0].startswith('module.')
         if (not flag_model) and flag_dict:
             model_state_dict = {k[7:]: v for k, v in model_state_dict.items()}
         if flag_model and (not flag_dict):
